<!--
https://pypi.org/project/readme-generator/
https://pypi.org/project/python-readme-generator/
-->

[![](https://img.shields.io/badge/OS-macOS-blue.svg?longCache=True)]()

#### Installation
```bash
$ [sudo] pip install mac-display
```

#### Scripts usage
command|`usage`
-|-
`display` |`usage: display sleep|state|wake`
`display-sleep` |`usage: display-sleep`
`display-state` |`usage: display-state`
`display-wake` |`usage: display-wake`

#### Examples
```bash
$ display sleep && display state
0
$ display wake && display state
1
```

<p align="center">
    <a href="https://pypi.org/project/python-readme-generator/">python-readme-generator</a>
</p>